@@ -15,6 +15,7 @@
 #include "application.h"
 #include "lsof.h"
 #include "lsof-data.h"
+#include "procinfo.h"
 #include "util.h"
 
 
@@ -75,20 +76,22 @@ struct GUI: private procman::NonCopyable
   GListStore *model;
   GtkSearchEntry *entry;
   GtkWindow *dialog;
-  GtkLabel *count;
   GsmApplication *app;
   bool case_insensitive;
-  bool regex_error_displayed;
 
 
-  GUI()
-    : model (NULL),
-    entry (NULL),
-    dialog (NULL),
-    count (NULL),
-    app (NULL),
-    case_insensitive (),
-    regex_error_displayed (false)
+  GUI(
+    GListStore *model_,
+    GtkSearchEntry *entry_,
+    GtkWindow *dialog_,
+    GsmApplication *app_,
+    bool case_insensitive_
+  )
+    : model (model_),
+    entry (entry_),
+    dialog (dialog_),
+    app (app_),
+    case_insensitive (case_insensitive_)
   {
     procman_debug ("New Lsof GUI %p", (void *)this);
   }
@@ -124,8 +127,6 @@ struct GUI: private procman::NonCopyable
   {
     typedef std::set<string> MatchSet;
 
-    bool regex_error = false;
-
     g_list_store_remove_all (this->model);
 
     try
@@ -157,13 +158,7 @@ struct GUI: private procman::NonCopyable
       }
     catch (Glib::RegexError &error)
       {
-        regex_error = true;
       }
-
-    if (regex_error && !this->regex_error_displayed)
-      this->regex_error_displayed = true;
-    else if (!regex_error && this->regex_error_displayed)
-      this->regex_error_displayed = false;
   }
 
   static void
@@ -206,13 +201,14 @@ procman_lsof (GsmApplication *app)
   gtk_search_bar_connect_entry (search_bar, GTK_EDITABLE (search_entry));
   gtk_search_bar_set_key_capture_widget (search_bar, GTK_WIDGET (dialog));
 
-  GUI *gui = new GUI;   // wil be deleted by the close button or delete-event
-
-  gui->app = app;
-  gui->model = model;
-  gui->dialog = dialog;
-  gui->entry = search_entry;
-  gui->case_insensitive = gtk_check_button_get_active (case_button);
+  // wil be deleted by the close button or delete-event
+  GUI *gui = new GUI(
+    model,
+    search_entry,
+    dialog,
+    app,
+    gtk_check_button_get_active (case_button)
+  );
 
   g_signal_connect (G_OBJECT (search_entry), "search-changed",
                     G_CALLBACK (GUI::search_changed), gui);
