@@ -47,20 +47,13 @@
 #include "prettytable.h"
 #include "util.h"
 #include "interface.h"
+#include "procinfo.h"
 #include "selinux.h"
 #include "settings-keys.h"
 #include "cgroups.h"
 #include "legacy/treeview.h"
 #include "systemd.h"
 
-ProcInfo*
-ProcList::find (pid_t pid)
-{
-  auto it = data.find (pid);
-
-  return (it == data.end () ? nullptr : &it->second);
-}
-
 static void
 cb_save_tree_state (gpointer,
                     gpointer data)
@@ -688,71 +681,6 @@ proctable_new (GsmApplication * const app)
   return proctree;
 }
 
-static void
-get_process_name (ProcInfo    *info,
-                  const gchar *cmd,
-                  const GStrv  args)
-{
-  if (args)
-    {
-      // look for /usr/bin/very_long_name
-      // and also /usr/bin/interpreter /usr/.../very_long_name
-      // which may have use prctl to alter 'cmd' name
-      for (int i = 0; i != 2 && args[i]; ++i)
-        {
-          char*basename;
-          basename = g_path_get_basename (args[i]);
-
-          if (g_str_has_prefix (basename, cmd))
-            {
-              info->name = make_string (basename);
-              return;
-            }
-
-          g_free (basename);
-        }
-    }
-  info->name = cmd;
-}
-
-std::string
-ProcInfo::lookup_user (guint uid)
-{
-  static std::map<guint, std::string> users;
-  auto p = users.insert ({ uid, "" });
-
-  // procman_debug("User lookup for uid %u: %s", uid, (p.second ? "MISS" : "HIT"));
-
-  if (p.second)
-    {
-      struct passwd*pwd;
-      pwd = getpwuid (uid);
-
-      if (pwd && pwd->pw_name)
-        {
-          p.first->second = pwd->pw_name;
-        }
-      else
-        {
-          char username[16];
-          g_sprintf (username, "%u", uid);
-          p.first->second = username;
-        }
-    }
-
-  return p.first->second;
-}
-
-void
-ProcInfo::set_user (guint uid)
-{
-  if (G_LIKELY (this->uid == uid))
-    return;
-
-  this->uid = uid;
-  this->user = lookup_user (uid);
-}
-
 void
 get_process_memory_writable (ProcInfo *info)
 {
@@ -802,7 +730,7 @@ update_info_mutable_cols (ProcInfo *info)
 
   model = gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER (
                                              gtk_tree_model_sort_get_model (GTK_TREE_MODEL_SORT (
-                                                                              gtk_tree_view_get_model (GTK_TREE_VIEW (GsmApplication::get ()->tree))))));
+                                                                              gtk_tree_view_get_model (GTK_TREE_VIEW (GsmApplication::get ().tree))))));
 
   using procman::tree_store_update;
 
@@ -1011,52 +939,6 @@ update_info (GsmApplication *app,
   procman::get_process_systemd_info (info);
 }
 
-ProcInfo::ProcInfo(pid_t pid)
-  : node (),
-  icon (),
-  pid (pid),
-  ppid (-1),
-  uid (-1)
-{
-  ProcInfo * const info = this;
-  glibtop_proc_state procstate;
-  glibtop_proc_time proctime;
-  glibtop_proc_args procargs;
-  gchar**arguments;
-
-  glibtop_get_proc_state (&procstate, pid);
-  glibtop_get_proc_time (&proctime, pid);
-  arguments = glibtop_get_proc_argv (&procargs, pid, 0);
-
-  /* FIXME : wrong. name and arguments may change with exec* */
-  get_process_name (info, procstate.cmd, static_cast<const GStrv>(arguments));
-
-  std::string tooltip = make_string (g_strjoinv (" ", arguments));
-
-  if (tooltip.empty ())
-    tooltip = procstate.cmd;
-
-  info->tooltip = make_string (g_markup_escape_text (tooltip.c_str (), -1));
-
-  info->arguments = make_string (g_strescape (tooltip.c_str (), "\\\""));
-  g_strfreev (arguments);
-
-  guint64 cpu_time = proctime.rtime;
-  auto app = GsmApplication::get ();
-  auto it = app->processes.cpu_times.find (pid);
-
-  if (it != app->processes.cpu_times.end ())
-    if (proctime.rtime >= it->second)
-      cpu_time = it->second;
-  info->cpu_time = cpu_time;
-  info->start_time = proctime.start_time;
-
-  get_process_selinux_context (info);
-  get_process_cgroup_info (*info);
-
-  get_process_systemd_info (info);
-}
-
 static void
 refresh_list (GsmApplication *app,
               const pid_t    *pid_list,
@@ -1269,21 +1151,6 @@ proctable_free_table (GsmApplication * const app)
   app->processes.clear ();
 }
 
-void
-ProcInfo::set_icon (Glib::RefPtr<Gdk::Texture> icon)
-{
-  this->icon = icon;
-
-  GtkTreeModel *model;
-
-  model = gtk_tree_model_filter_get_model (GTK_TREE_MODEL_FILTER (
-                                             gtk_tree_model_sort_get_model (GTK_TREE_MODEL_SORT (
-                                                                              gtk_tree_view_get_model (GTK_TREE_VIEW (GsmApplication::get ()->tree))))));
-  gtk_tree_store_set (GTK_TREE_STORE (model), &this->node,
-                      COL_ICON, (this->icon ? this->icon->gobj () : NULL),
-                      -1);
-}
-
 void
 proctable_freeze (GsmApplication *app)
 {
