@@ -15,6 +15,10 @@
 #define GSM_SETTING_WINDOW_HEIGHT           "window-height"
 #define GSM_SETTING_MAXIMIZED               "maximized"
 #define GSM_SETTING_CURRENT_TAB             "current-tab"
+#define GSM_SETTING_RESOURCES_CPU_EXPANDED  "resources-cpu-expanded"
+#define GSM_SETTING_RESOURCES_MEM_EXPANDED  "resources-mem-expanded"
+#define GSM_SETTING_RESOURCES_NET_EXPANDED  "resources-net-expanded"
+#define GSM_SETTING_RESOURCES_DISK_EXPANDED "resources-disk-expanded"
 #define GSM_SETTING_PROCESS_UPDATE_INTERVAL "update-interval"
 #define GSM_SETTING_SHOW_WHOSE_PROCESSES    "show-whose-processes"
 #define GSM_SETTING_SHOW_DEPENDENCIES       "show-dependencies"
