@@ -1,7 +1,7 @@
 #ifndef PROCMAN_SYSTEMD_H_144CA8D6_BF03_11E4_B291_000C298F6617
 #define PROCMAN_SYSTEMD_H_144CA8D6_BF03_11E4_B291_000C298F6617
 
-#include "application.h"
+#include "procinfo.h"
 
 namespace procman
 {
